@@ -7,18 +7,18 @@ foo <- function(x){
 test_that("Lists over nested functions produce the correct output", {
   # the results is a list of Rmonads
   expect_equal(
-    -1:1 %>>% { lapply(., foo) } %>% {sapply(m_value(.), is_rmonad)},
+    -1:1 %>>% { lapply(., foo) } %>% {sapply(.single_value(.), is_rmonad)},
     c(TRUE, TRUE, TRUE)
   )
   # binding this to `combine` performs the operation
   #   m [m a] -> m [a]
   expect_equal(
-    -1:1 %>>% { lapply(., foo) } %>>% combine %>% m_value,
+    -1:1 %>>% { lapply(., foo) } %>>% combine %>% .single_value,
     list(TRUE, FALSE, FALSE)
   )
 
   expect_equal(
-    -1:1 %>%  { lapply(., foo) } %>%  combine %>% m_value,
-    -1:1 %>>% { lapply(., foo) } %>>% combine %>% m_value
+    -1:1 %>%  { lapply(., foo) } %>%  combine %>% .single_value,
+    -1:1 %>>% { lapply(., foo) } %>>% combine %>% .single_value
   )
 })
